@@ -1,13 +1,14 @@
 from .GcodeFile import GcodeFile
+from .Filament import Filament
 import json
 from typing import Optional, Any
 from pydantic import BaseModel, Field
 class Job(BaseModel): 
-  file: Optional[GcodeFile] = Field()
-  estimatedPrintTime: Optional[str] = Field()
-  lastPrintTime: Optional[str] = Field()
-  filamentLength: Optional[str] = Field()
-  filamentVolume: Optional[str] = Field()
+  file: GcodeFile = Field()
+  averagePrintTime: Optional[float] = Field()
+  estimatedPrintTime: float = Field()
+  lastPrintTime: float = Field()
+  filaments: Optional[list[Filament]] = Field()
 
   def serializeToJson(self):
     return json.dumps(self.__dict__, default=lambda o: o.__dict__, indent=2)
