@@ -1,8 +1,10 @@
+from .Job import Job
 from .PrinterStatus import PrinterStatus
 import json
 from typing import Optional, Any
 from pydantic import BaseModel, Field
 class PrinterStatusChanged(BaseModel): 
+  job: Optional[Job] = Field()
   status: PrinterStatus = Field()
 
   def serializeToJson(self):
